#
# spec file for package tomcat
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2000-2009, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define jspspec 2.3
%define servletspec 4.0
%define elspec 3.0
%define major_version 9
%define minor_version 0
%define micro_version 33
%define packdname apache-tomcat-%{version}-src
# FHS 2.3 compliant tree structure - http://www.pathname.com/fhs/2.3/
%global basedir /srv/%{name}
%define appdir %{basedir}/webapps
%define bindir %{_datadir}/%{name}/bin
%define confdir %{_sysconfdir}/%{name}
%define homedir %{_datadir}/%{name}
%define libdir %{_javadir}/%{name}
%define logdir %{_localstatedir}/log/%{name}
%define cachedir %{_localstatedir}/cache/%{name}
%define tempdir %{cachedir}/temp
%define workdir %{cachedir}/work
%define tomcatappdir %{_datadir}/%{name}/tomcat-webapps
%define serverxmltool %{_libexecdir}/%{name}/serverxml-tool.sh
%define javac_target 1.8
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           tomcat
Version:        %{major_version}.%{minor_version}.%{micro_version}
Release:        lp151.3.15.1
Summary:        Apache Servlet/JSP/EL Engine, RI for Servlet 4.0/JSP 2.3/EL 3.0 API
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://tomcat.apache.org
Source0:        https://archive.apache.org/dist/tomcat/tomcat-%{major_version}/v%{version}/src/%{packdname}.tar.gz
Source1:        %{name}-%{major_version}.%{minor_version}.conf
Source2:        %{name}-%{major_version}.%{minor_version}.init
Source3:        %{name}-%{major_version}.%{minor_version}.sysconfig
Source4:        %{name}-%{major_version}.%{minor_version}.wrapper
Source5:        %{name}-%{major_version}.%{minor_version}.logrotate
Source6:        %{name}-%{major_version}.%{minor_version}-digest.script
Source7:        %{name}-%{major_version}.%{minor_version}-tool-wrapper.script
Source8:        servlet-api-OSGi-MANIFEST.MF
Source9:        jsp-api-OSGi-MANIFEST.MF
Source10:       %{name}-%{major_version}.%{minor_version}-log4j.properties
Source11:       %{name}-%{major_version}.%{minor_version}.service
Source12:       el-api-OSGi-MANIFEST.MF
Source13:       jasper-el-OSGi-MANIFEST.MF
Source14:       jasper-OSGi-MANIFEST.MF
Source15:       tomcat-api-OSGi-MANIFEST.MF
Source16:       tomcat-juli-OSGi-MANIFEST.MF
Source20:       %{name}-%{major_version}.%{minor_version}-jsvc.service
Source21:       tomcat-functions
Source30:       tomcat-preamble
Source31:       tomcat-server
Source32:       tomcat-named.service
Source33:       tomcat-serverxml-tool.tar.gz
Source34:       tomcat-serverxml-tool.sh
Source1000:     tomcat-rpmlintrc
Source1001:     https://archive.apache.org/dist/tomcat/tomcat-%{major_version}/v%{version}/src/%{packdname}.tar.gz.asc
Source1002:     %{name}.keyring
#PATCH-FIX-UPSTREAM: from jpackage.org package
Patch0:         %{name}-%{major_version}.%{minor_version}-bootstrap-MANIFEST.MF.patch
#PATCH-FIX-UPSTREAM: from jpackage.org package
Patch1:         %{name}-%{major_version}.%{minor_version}-tomcat-users-webapp.patch
# PATCH-FIX-UPSTREAM: https://issues.apache.org/bugzilla/show_bug.cgi?id=56373
Patch2:         %{name}-%{major_version}.%{minor_version}-JDTCompiler-java.patch
# PATCH-FIX-SLE: Change security manager default policies bnc#891264
Patch3:         %{name}-%{major_version}.%{minor_version}-sle.catalina.policy.patch
# PATCH-FIX-OPENSUSE: build javadoc with the same java source level as the class files
Patch4:         %{name}-%{major_version}.%{minor_version}-javadoc.patch
# PATCH-FIX-OPENSUSE: disable adding OSGi metadata to JAR files because bndtools is not avalable in SLES/OpenSUSE
Patch5:         tomcat-9.0-disable-osgi-build.patch
# PATCH-FIX-OPENSUSE: cast ByteBuffer to Buffer in cases where there is a risk of using Java 9+ apis
Patch6:         tomcat-9.0.31-java8compat.patch
# PATCH-FIX-OPENSUSE: set ajp connector secreteRequired to false by default to avoid tomcat not starting
Patch7:         tomcat-9.0.31-secretRequired-default.patch

BuildRequires:  ant >= 1.8.1
BuildRequires:  ant-antlr
BuildRequires:  apache-commons-collections
BuildRequires:  apache-commons-daemon
BuildRequires:  apache-commons-dbcp >= 2.0
BuildRequires:  apache-commons-pool2
BuildRequires:  ecj >= 4.4.0
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  geronimo-jaf-1_0_2-api
BuildRequires:  geronimo-jaxrpc-1_1-api
BuildRequires:  geronimo-qname-1_1-api
BuildRequires:  geronimo-saaj-1_1-api
BuildRequires:  jakarta-taglibs-standard >= 1.1
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
BuildRequires:  junit
BuildRequires:  log4j
BuildRequires:  sed
BuildRequires:  systemd
BuildRequires:  systemd-rpm-macros
BuildRequires:  unzip
BuildRequires:  wsdl4j
BuildRequires:  zip
Requires:       %{name}-lib = %{version}-%{release}
Requires:       apache-commons-daemon
Requires:       apache-commons-dbcp
Requires:       apache-commons-logging
Requires:       apache-commons-pool2
Requires:       java >= 1.8
Requires:       log4j
Requires(post): %fillup_prereq
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
Recommends:     libtcnative-1-0 >= 1.1.24
Recommends:     logrotate
BuildArch:      noarch
%systemd_requires

%description
Tomcat is the servlet container that is used in the official Reference
Implementation for the Java Servlet and JavaServer Pages technologies.
The Java Servlet and JavaServer Pages specifications are developed by
Sun under the Java Community Process.

Tomcat is developed in an open and participatory environment and
released under the Apache Software License version 2.0. Tomcat is
intended to be a collaboration of the best-of-breed developers from
around the world.

ATTENTION: This tomcat is built with java 1.8.0.

%package admin-webapps
Summary:        The host manager and manager web applications for Apache Tomcat
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}

%description admin-webapps
The host manager and manager web-based applications for Apache Tomcat.

%package embed
Summary:        Libraries for Embedding Apache Tomcat
Group:          Productivity/Networking/Web/Servers

%description embed
Embeddeding support (various libraries) for Apache Tomcat.

%package docs-webapp
Summary:        The "docs" web application for Apache Tomcat
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}

%description docs-webapp
The documentation of web application for Apache Tomcat.

%package el-3_0-api
Summary:        Expression Language v3.0 API
Group:          Development/Libraries/Java
Requires(post): update-alternatives
Requires(preun): update-alternatives
Provides:       %{name}-el-%{elspec}-api = %{version}-%{release}
Provides:       el_3_0_api = %{version}-%{release}
Provides:       el_api = %{elspec}
Obsoletes:      el_api < %{elspec}
Obsoletes:      tomcat-el-2_2-api

%description el-3_0-api
Expression Language API version 3.0.

%package javadoc
Summary:        Javadoc generated documentation for Apache Tomcat
Group:          Documentation/HTML

%description javadoc
Javadoc generated documentation files for Apache Tomcat.

%package jsp-2_3-api
Summary:        Apache Tomcat JSP API implementation classes
Group:          Productivity/Networking/Web/Servers
Requires:       mvn(org.apache.tomcat:tomcat-el-api)
Requires:       mvn(org.apache.tomcat:tomcat-servlet-api)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       %{name}-jsp-%{jspspec}-api
Provides:       jsp = %{jspspec}
Provides:       jsp23
Obsoletes:      jsp < %{jspspec}
Obsoletes:      tomcat-jsp-2_2-api

%description jsp-2_3-api
Apache Tomcat JSP API implementation classes version 2.3

%package jsvc
Summary:        Apache jsvc wrapper for Apache Tomcat as separate service
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}
Requires:       apache-commons-daemon-jsvc

%description jsvc
Systemd service and wrapper scripts to start tomcat with jsvc,
which allows tomcat to perform some privileged operations
(e.g. bind to a port < 1024) and then switch identity to a non-privileged user.

%package lib
Summary:        Libraries needed to run the Tomcat Web container
Group:          Productivity/Networking/Web/Servers
Requires:       %{name}-el-%{elspec}-api = %{version}-%{release}
Requires:       %{name}-jsp-%{jspspec}-api = %{version}-%{release}
Requires:       %{name}-servlet-%{servletspec}-api = %{version}-%{release}
Requires(post): ecj >= 4.4
Requires(preun): coreutils
Provides:       jakarta-commons-dbcp-tomcat5 = 1.4
Obsoletes:      jakarta-commons-dbcp-tomcat5 < 1.4

%description lib
Libraries required to successfully run the Tomcat Web container

%package servlet-4_0-api
Summary:        Apache Tomcat Servlet API implementation classes
Group:          Productivity/Networking/Web/Servers
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       %{name}-servlet-%{servletspec}-api = %{version}-%{release}
Provides:       servlet = %{servletspec}
Provides:       servlet31
Provides:       servlet7
Obsoletes:      servlet < %{servletspec}
Obsoletes:      tomcat-servlet-3_0-api
Obsoletes:      tomcat-servlet-3_1-api

%description servlet-4_0-api
Apache Tomcat Servlet API implementation classes version 3.1

%package webapps
Summary:        ROOT and examples web applications for Apache Tomcat
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}
Requires:       jakarta-taglibs-standard >= 1.1

%description webapps
The ROOT and examples web applications for Apache Tomcat

%prep
%setup -q -n %{packdname} -b33

# remove pre-built binaries and windows files
find . -type f \( -name "*.bat" -o -name "*.class" -o -name Thumbs.db -o -name "*.gz" -o \
          -name "*.jar" -o -name "*.war" -o -name "*.zip" \) -print -delete
%patch0
%patch1
%patch2 -p1
%patch3
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

# remove date from docs
sed -i -e '/build-date/ d' webapps/docs/tomcat-docs.xsl

%build

ln -s $(build-classpath jakarta-taglibs-core) webapps/examples/WEB-INF/lib/jstl.jar
ln -s $(build-classpath jakarta-taglibs-standard) webapps/examples/WEB-INF/lib/standard.jar

export CLASSPATH=
export OPT_JAR_LIST="xalan-j2-serializer"
export ANT_OPTS=-Xmx500M

# we don't care about the tarballs and we're going to replace
# so just create a dummy file for later removal
touch HACK
mkdir -p HACKDIR
touch HACKDIR/build.xml

ant -Dbase.path="." \
    -Djava.7.home="%{java_home}" \
    -Dbuild.compiler="modern" \
    -Dcommons-collections.jar="$(build-classpath commons-collections)" \
    -Dcommons-daemon.jar="$(build-classpath commons-daemon)" \
    -Dcommons-daemon.native.src.tgz="HACK" \
    -Djasper-jdt.jar="$(build-classpath ecj)" \
    -Djdt.jar="$(build-classpath ecj)" \
    -Dtomcat-native.tar.gz="HACK" \
    -Dtomcat-native.home="." \
    -Dcommons-daemon.native.win.mgr.exe="HACK" \
    -Dnsis.exe="HACK" \
    -Djaxrpc-lib.jar="$(build-classpath jaxrpc)" \
    -Dwsdl4j-lib.jar="$(build-classpath wsdl4j)" \
    -Dsaaj-api.jar="$(build-classpath geronimo-saaj-1_1-api)" \
    -Dcommons-pool.home="$(build-classpath commons-pool2)" \
    -Dcommons-dbcp.home="$(build-classpath commons-dbcp2)" \
    -Dno.build.dbcp=true \
    -Dversion="%{version}" \
    -Dversion.build="%{micro_version}" \
    deploy dist-prepare dist-source javadoc package embed-jars

# remove some jars that we'll replace with symlinks later
rm output/build/bin/commons-daemon.jar \
        output/build/lib/ecj.jar

pushd output/dist/src/webapps/docs/appdev/sample/src
mkdir -p ../web/WEB-INF/classes
javac -source %{javac_target} -target %{javac_target} -cp ../../../../../../../../output/build/lib/servlet-api.jar -d ../web/WEB-INF/classes mypackage/Hello.java
pushd ../web
jar cf ../../../../../../../../output/build/webapps/docs/appdev/sample/sample.war *
popd
popd

# inject OSGi manifests
jar ufm output/build/lib/servlet-api.jar %{SOURCE8}
jar ufm output/build/lib/jsp-api.jar %{SOURCE9}
jar ufm output/build/lib/el-api.jar %{SOURCE12}
jar ufm output/build/lib/jasper-el.jar %{SOURCE13}
jar ufm output/build/lib/jasper.jar %{SOURCE14}
jar ufm output/build/lib/tomcat-api.jar %{SOURCE15}
jar ufm output/build/bin/tomcat-juli.jar %{SOURCE16}

pushd %{_builddir}/tomcat-serverxml-tool
javac -source %{javac_target} -target %{javac_target} com/suse/tcserverxml/ApplyStylesheet.java
jar cfe serverxmltool.jar com.suse.tcserverxml.ApplyStylesheet com/suse/tcserverxml/ApplyStylesheet.class com/suse/tcserverxml/add-context.xslt com/suse/tcserverxml/remove-context.xslt
popd

%install
%if 0%{?suse_version} == 1110
export NO_BRP_CHECK_BYTECODE_VERSION=true
%endif
# build initial path structure
install -d -m 0755 %{buildroot}%{_bindir}
install -d -m 0755 %{buildroot}%{_sbindir}
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
install -d -m 0755 %{buildroot}%{_initddir}
install -d -m 0755 %{buildroot}%{_systemddir}
install -d -m 0755 %{buildroot}%{_sysconfdir}/logrotate.d
install -d -m 0755 %{buildroot}%{_sysconfdir}/sysconfig
install -d -m 0755 %{buildroot}%{appdir}
install -d -m 0755 %{buildroot}%{tomcatappdir}
install -d -m 0755 %{buildroot}%{bindir}
install -d -m 0775 %{buildroot}%{confdir}
install -d -m 0755 %{buildroot}%{cachedir}/Catalina/localhost
install -d -m 0775 %{buildroot}%{confdir}/conf.d
/bin/echo "Place your custom *.conf files here. Shell expansion is supported." > %{buildroot}%{confdir}/conf.d/README
install -d -m 0755 %{buildroot}%{libdir}
install -d -m 0775 %{buildroot}%{logdir}
/bin/touch %{buildroot}%{logdir}/catalina.out
install -d -m 0775 %{buildroot}%{_localstatedir}/lib/tomcats
/bin/echo "%{name}-%{major_version}.%{minor_version}.%{micro_version} RPM installed" >> %{buildroot}%{logdir}/catalina.out
install -d -m 0775 %{buildroot}%{homedir}
install -d -m 0775 %{buildroot}%{tempdir}
install -d -m 0775 %{buildroot}%{workdir}
install -d -m 0755 %{buildroot}%{_unitdir}
install -d -m 0755 %{buildroot}%{_libexecdir}/%{name}
install -d -m 0755 %{buildroot}%{_fillupdir}

# move things into place
# First copy supporting libs to tomcat lib
pushd output/build
    cp -a bin/*.{jar,xml} %{buildroot}%{bindir}
    cp %{SOURCE10} conf/log4j.properties
    cp -a conf/*.{policy,properties,xml} %{buildroot}%{confdir}
    cp -a lib/*.jar %{buildroot}%{libdir}
    cp -a webapps/* %{buildroot}%{tomcatappdir}
popd
# tomcat embedded
pushd output/embed
    cp -a *.jar %{buildroot}%{libdir}
popd

# javadoc
cp -a output/dist/webapps/docs/api/* %{buildroot}%{_javadocdir}/%{name}

sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE1} \
    > %{buildroot}%{confdir}/%{name}.conf
sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE3} \
    > %{buildroot}%{_fillupdir}/sysconfig.%{name}
install -m 0644 %{SOURCE4} \
    %{buildroot}%{_sbindir}/%{name}
install -m 0644 %{SOURCE11} \
    %{buildroot}%{_unitdir}/%{name}.service
install -m 0644 %{SOURCE20} \
    %{buildroot}%{_unitdir}/%{name}-jsvc.service
sed -e "s|\@\@\@TCLOG\@\@\@|%{logdir}|g" %{SOURCE5} \
    > %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE6} \
    > %{buildroot}%{_bindir}/%{name}-digest
sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE7} \
    > %{buildroot}%{_bindir}/%{name}-tool-wrapper

install -m 0644 %{SOURCE21} \
    %{buildroot}%{_libexecdir}/%{name}/functions
install -m 0755 %{SOURCE30} \
    %{buildroot}%{_libexecdir}/%{name}/preamble
install -m 0755 %{SOURCE31} \
    %{buildroot}%{_libexecdir}/%{name}/server
install -m 0644 %{SOURCE32} \
    %{buildroot}%{_unitdir}/%{name}@.service

ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}-jsvc

# create jsp and servlet and el API symlinks
pushd %{buildroot}%{_javadir}
   mv %{name}/jsp-api.jar %{name}-jsp-%{jspspec}-api.jar
   ln -s %{name}-jsp-%{jspspec}-api.jar %{name}-jsp-api.jar
   mv %{name}/servlet-api.jar %{name}-servlet-%{servletspec}-api.jar
   ln -s %{name}-servlet-%{servletspec}-api.jar %{name}-servlet-api.jar
   mv %{name}/el-api.jar %{name}-el-%{elspec}-api.jar
   ln -s %{name}-el-%{elspec}-api.jar %{name}-el-api.jar
popd

pushd output/build
    %{_bindir}/build-jar-repository lib commons-collections \
                                        commons-dbcp2 commons-pool2 ecj 2>&1
    # need to use -p here with b-j-r otherwise the examples webapp fails to
    # load with a java.io.IOException
    %{_bindir}/build-jar-repository -p webapps/examples/WEB-INF/lib \
    taglibs-core.jar taglibs-standard.jar 2>&1
popd

pushd %{buildroot}%{libdir}
    # symlink JSP and servlet and el API jars
    ln -s ../%{name}-jsp-%{jspspec}-api.jar .
    ln -s ../%{name}-servlet-%{servletspec}-api.jar .
    ln -s ../%{name}-el-%{elspec}-api.jar .
    ln -s $(build-classpath commons-collections) commons-collections.jar
    rm -f commons-dbcp.jar
    ln -s $(build-classpath commons-dbcp2) commons-dbcp2.jar
    ln -s $(build-classpath commons-pool2) commons-pool2.jar
    ln -s $(build-classpath log4j) log4j.jar
    ln -s $(build-classpath ecj) jasper-jdt.jar

    # Temporary copy the juli jar here from %%{_datadir}/java/tomcat (for maven depmap)
    cp -a %{buildroot}%{bindir}/tomcat-juli.jar ./
popd

# symlink to the FHS locations where we've installed things
pushd %{buildroot}%{homedir}
    ln -s %{appdir} webapps
    ln -s %{confdir} conf
    ln -s %{libdir} lib
    ln -s %{logdir} logs
    ln -s %{tempdir} temp
    ln -s %{workdir} work
popd

# install sample webapp
mkdir -p %{buildroot}%{tomcatappdir}/sample
pushd %{buildroot}%{tomcatappdir}/sample
%jar xf %{buildroot}%{tomcatappdir}/docs/appdev/sample/sample.war
popd

# Allow linking for example webapp
mkdir -p %{buildroot}%{tomcatappdir}/examples/META-INF
pushd %{buildroot}%{tomcatappdir}/examples/META-INF
echo '<?xml version="1.0" encoding="UTF-8"?>'>context.xml
echo '<Context>'>>context.xml
echo '  <Resources allowLinking="true" />'>>context.xml
echo '</Context>'>>context.xml
popd

pushd %{buildroot}%{tomcatappdir}/examples/WEB-INF/lib
ln -s -f $(build-classpath jakarta-taglibs-core) jstl.jar
ln -s -f $(build-classpath jakarta-taglibs-standard) standard.jar
popd

rm %{buildroot}%{tomcatappdir}/docs/appdev/sample/sample.war

# Install the maven metadata
install -d -m 0755 %{buildroot}%{_mavenpomdir}
pushd output/dist/src/res/maven
for pom in *.pom; do
    # fix-up version in all pom files
    sed -i 's/@MAVEN.DEPLOY.VERSION@/%{version}/g' $pom
done

# we won't install dbcp, juli-adapters and juli-extras pom files
for libname in annotations-api catalina jasper-el jasper catalina-ha; do
    cp -a %{name}-$libname.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-$libname.pom
    %add_maven_depmap JPP.%{name}-$libname.pom %{name}/$libname.jar
done

# servlet-api jsp-api and el-api are not in tomcat subdir, since they are widely re-used elsewhere
cp -a tomcat-jsp-api.pom %{buildroot}%{_mavenpomdir}/JPP-tomcat-jsp-api.pom
%add_maven_depmap JPP-tomcat-jsp-api.pom tomcat-jsp-api.jar -f jsp-api -a "org.eclipse.jetty.orbit:javax.servlet.jsp"

cp -a tomcat-el-api.pom %{buildroot}%{_mavenpomdir}/JPP-tomcat-el-api.pom
%add_maven_depmap JPP-tomcat-el-api.pom tomcat-el-api.jar -f el-api -a "org.eclipse.jetty.orbit:javax.el"

cp -a tomcat-servlet-api.pom %{buildroot}%{_mavenpomdir}/JPP-tomcat-servlet-api.pom
# Generate a depmap fragment javax.servlet:servlet-api pointing to
# tomcat-servlet-3.0-api for backwards compatibility
# also provide jetty depmap (originally in jetty package, but it's cleaner to have it here
%add_maven_depmap JPP-tomcat-servlet-api.pom tomcat-servlet-api.jar -f servlet-api -a "org.mortbay.jetty:servlet-api"

# two special pom where jar files have different names
cp -a tomcat-tribes.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-catalina-tribes.pom
%add_maven_depmap JPP.%{name}-catalina-tribes.pom %{name}/catalina-tribes.jar

cp -a tomcat-coyote.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-coyote.pom
%add_maven_depmap JPP.%{name}-tomcat-coyote.pom %{name}/tomcat-coyote.jar

cp -a tomcat-juli.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-juli.pom
%add_maven_depmap JPP.%{name}-tomcat-juli.pom %{name}/tomcat-juli.jar

cp -a tomcat-jdbc.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-jdbc.pom
%add_maven_depmap JPP.%{name}-tomcat-jdbc.pom %{name}/tomcat-jdbc.jar

cp -a tomcat-dbcp.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-dbcp.pom
%add_maven_depmap JPP.%{name}-tomcat-dbcp.pom %{name}/tomcat-dbcp.jar

cp -a tomcat-api.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-api.pom
%add_maven_depmap JPP.%{name}-tomcat-api.pom %{name}/tomcat-api.jar

cp -a tomcat-util.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-util.pom
%add_maven_depmap JPP.%{name}-tomcat-util.pom %{name}/tomcat-util.jar

cp -a tomcat-websocket-api.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-websocket-api.pom
%add_maven_depmap JPP.%{name}-websocket-api.pom %{name}/websocket-api.jar

cp -a tomcat-websocket.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-websocket.pom
%add_maven_depmap JPP.%{name}-tomcat-websocket.pom %{name}/tomcat-websocket.jar

cp -a tomcat-embed-core.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-core.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-core.pom %{name}/tomcat-embed-core.jar -f embed

cp -a tomcat-embed-el.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-el.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-el.pom %{name}/tomcat-embed-el.jar -f embed

cp -a tomcat-embed-jasper.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-jasper.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-jasper.pom %{name}/tomcat-embed-jasper.jar -f embed

%add_maven_depmap JPP.%{name}-websocket-api.pom %{name}/websocket-api.jar

cp -a tomcat-embed-websocket.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-websocket.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-websocket.pom %{name}/tomcat-embed-websocket.jar -f embed

# replace temporary copy with link
ln -s -f %{bindir}/tomcat-juli.jar %{buildroot}%{libdir}/

# bnc#424675
ln -s %{cachedir}/Catalina %{buildroot}/%{confdir}
rm -rf %{buildroot}/%{confdir}/Catalina
ln -s %{cachedir}/Catalina %{buildroot}/%{confdir}/

# bnc#418664
install -d -m 0755 %{buildroot}/%{_sysconfdir}/ant.d/
echo "%{name}/catalina-ant" > %{buildroot}/%{_sysconfdir}/ant.d/catalina-ant
%fdupes %{buildroot} /srv/%{name}
#bnc#565901
ln -sf %{_sbindir}/%{name} %{buildroot}/%{bindir}/catalina.sh

# Install update-alternatives content
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/el_api %{buildroot}%{_javadir}/%{name}-el_api.jar
ln -s -f %{_sysconfdir}/alternatives/el_1_0_api %{buildroot}%{_javadir}/%{name}-el_1_0_api.jar
ln -s -f %{_sysconfdir}/alternatives/jsp %{buildroot}%{_javadir}/%{name}-jsp.jar
ln -s -f %{_sysconfdir}/alternatives/servlet %{buildroot}%{_javadir}/%{name}-servlet.jar

mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf <<EOF
f %{_localstatedir}/run/%{name}.pid 0644 tomcat tomcat -
EOF

# Install tool used to edit server.xml
pushd %{_builddir}/tomcat-serverxml-tool
install -m 0755 %{SOURCE34} \
    %{buildroot}%{_libexecdir}/%{name}/serverxml-tool.sh
cp serverxmltool.jar %{buildroot}%{_libexecdir}/%{name}/
popd

%pre
# add the tomcat user and group
%{_sbindir}/groupadd -r tomcat 2>/dev/null || :
%{_sbindir}/useradd -c "Apache Tomcat" -g tomcat \
    -s /bin/sh -r -d %{homedir} tomcat 2>/dev/null || :
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%{fillup_only %{name}}
%{_bindir}/systemd-tmpfiles --create  >/dev/null 2>&1 || :

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%pre jsvc
%service_add_pre %{name}-jsvc.service

%post jsvc
%service_add_post %{name}-jsvc.service

%preun jsvc
%service_del_preun %{name}-jsvc.service

%postun jsvc
%service_del_postun %{name}-jsvc.service

%post el-3_0-api
update-alternatives --install %{_javadir}/%{name}-el_api.jar el_api %{_javadir}/%{name}-el-%{elspec}-api.jar 20300
update-alternatives --install %{_javadir}/%{name}-el_1_0_api.jar el_1_0_api %{_javadir}/%{name}-el-%{elspec}-api.jar 20300

%preun el-3_0-api
if [ $1 -eq 0 ] ; then
    update-alternatives --remove el_api %{_javadir}/%{name}-el-%{elspec}-api.jar
    update-alternatives --remove el_1_0_api %{_javadir}/%{name}-el-%{elspec}-api.jar
fi

%post jsp-2_3-api
update-alternatives --install %{_javadir}/%{name}-jsp.jar jsp \
    %{_javadir}/%{name}-jsp-%{jspspec}-api.jar 20200

%postun jsp-2_3-api
if [ $1 -eq 0 ] ; then
    update-alternatives --remove jsp \
        %{_javadir}/%{name}-jsp-%{jspspec}-api.jar
fi

%post servlet-4_0-api
update-alternatives --install %{_javadir}/%{name}-servlet.jar servlet \
    %{_javadir}/%{name}-servlet-%{servletspec}-api.jar 30000

%postun servlet-4_0-api
if [ $1 -eq 0 ] ; then
    update-alternatives --remove servlet \
        %{_javadir}/%{name}-servlet-%{servletspec}-api.jar
fi

%post lib
# those links are no longer needed
rm -f \
    %{libdir}/\[commons-collections-tomcat5\].jar \
    %{libdir}/\[commons-dbcp-tomcat5\].jar \
    %{libdir}/\[commons-pool-tomcat5\].jar \
    %{libdir}/\[ecj\].jar >/dev/null 2>&1

%post webapps
%{serverxmltool} add %{tomcatappdir}/ROOT /
%{serverxmltool} add %{tomcatappdir}/sample /sample
%{serverxmltool} add %{tomcatappdir}/examples /examples

%postun webapps
if [ $1 -eq 0 ]; then # uninstall only
  %{serverxmltool} remove %{tomcatappdir}/ROOT /
  %{serverxmltool} remove %{tomcatappdir}/sample /sample
  %{serverxmltool} remove %{tomcatappdir}/examples /example
fi

%post admin-webapps
%{serverxmltool} add %{tomcatappdir}/host-manager /host-manager %{tomcatappdir}/host-manager/META-INF/context.xml
%{serverxmltool} add %{tomcatappdir}/manager /manager %{tomcatappdir}/manager/META-INF/context.xml

%postun admin-webapps
if [ $1 -eq 0 ]; then # uninstall only
  %{serverxmltool} remove %{tomcatappdir}/host-manager /host-manager
  %{serverxmltool} remove %{tomcatappdir}/manager /manager
fi

%post docs-webapp
%{serverxmltool} add %{tomcatappdir}/docs /docs

%postun docs-webapp
if [ $1 -eq 0 ]; then # uninstall only
  %{serverxmltool} remove %{tomcatappdir}/docs /docs
fi

%files
%defattr(0664,root,tomcat,0755)
%doc {LICENSE,NOTICE,RELEASE*}
%attr(0755,root,root) %{_bindir}/%{name}-digest
%attr(0755,root,root) %{_bindir}/%{name}-tool-wrapper
%attr(0755,root,root) %{_sbindir}/%{name}
%attr(0644,root,root) %{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%attr(0644,root,root) %{_unitdir}/%{name}@.service
%attr(0755,root,root) %dir %{_libexecdir}/%{name}
%attr(0755,root,root) %dir %{_localstatedir}/lib/tomcats
%attr(0755,root,root) %{_libexecdir}/%{name}/functions
%attr(0755,root,root) %{_libexecdir}/%{name}/preamble
%attr(0755,root,root) %{_libexecdir}/%{name}/server
%attr(0755,root,root) %{_libexecdir}/%{name}/serverxml-tool.sh
%attr(0644,root,root) %{_libexecdir}/%{name}/serverxmltool.jar
#bnc#565901
%{bindir}/catalina.sh
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(0755,root,tomcat) %dir %{basedir}
%attr(0755,root,tomcat) %dir %{confdir}
%defattr(0664,tomcat,root,0770)
%attr(0775,root,tomcat) %dir %{appdir}
%attr(0770,tomcat,root) %{logdir}
%attr(0660,tomcat,tomcat) %{logdir}/catalina.out
%attr(0770,root,tomcat) %{cachedir}
%defattr(0664,root,tomcat,0770)
%attr(0770,root,tomcat) %dir %{tempdir}
%attr(0770,root,tomcat) %dir %{workdir}
%attr(0775,root,tomcat) %dir %{tomcatappdir}
# tomcat group writtable dirs - bnc#625415
%defattr(0664,root,tomcat,0775)
%{confdir}/Catalina
%attr(0775,root,tomcat) %dir %{confdir}/conf.d
%attr(0664,tomcat,tomcat) %{confdir}/conf.d/README
%attr(0664,tomcat,tomcat) %config(noreplace) %{confdir}/%{name}.conf
%attr(0664,tomcat,tomcat) %config(noreplace) %{confdir}/*.policy
%attr(0664,tomcat,tomcat) %config(noreplace) %{confdir}/*.properties
%attr(0664,tomcat,tomcat) %config(noreplace) %{confdir}/context.xml
%attr(0664,tomcat,tomcat) %config(noreplace) %{confdir}/server.xml
%attr(0660,tomcat,tomcat) %config(noreplace) %{confdir}/tomcat-users.xml
%attr(0664,tomcat,tomcat) %config(noreplace) %{confdir}/web.xml
%attr(0664,tomcat,tomcat) %config(noreplace) %{confdir}/jaspic-providers.xml
%dir %{homedir}
%{_tmpfilesdir}/%{name}.conf
%{bindir}/bootstrap.jar
%{bindir}/catalina-tasks.xml
%{homedir}/lib
%{homedir}/temp
%{homedir}/webapps
%{homedir}/work
%{homedir}/logs
%{homedir}/conf
%{_fillupdir}/sysconfig.%{name}

%files admin-webapps
%{tomcatappdir}/host-manager
%config(noreplace) %{tomcatappdir}/host-manager/META-INF/context.xml
%{tomcatappdir}/manager
%config(noreplace) %{tomcatappdir}/manager/META-INF/context.xml

%files docs-webapp
%{tomcatappdir}/docs

%files el-3_0-api -f output/dist/src/res/maven/.mfiles-el-api
%{_javadir}/%{name}-el-%{elspec}-api.jar
%{_javadir}/%{name}-el-api.jar
%{libdir}/%{name}-el-%{elspec}-api.jar
%{_javadir}/%{name}-el_1_0_api.jar
%{_javadir}/%{name}-el_api.jar
%ghost %{_sysconfdir}/alternatives/el_1_0_api
%ghost %{_sysconfdir}/alternatives/el_api

%files javadoc
%doc %{_javadocdir}/%{name}

%files jsp-2_3-api -f output/dist/src/res/maven/.mfiles-jsp-api
%{_javadir}/%{name}-jsp-%{jspspec}-api.jar
%{_javadir}/%{name}-jsp-api.jar
%{_javadir}/%{name}-jsp.jar
%ghost %{_sysconfdir}/alternatives/jsp

%files lib -f output/dist/src/res/maven/.mfiles
%{libdir}
%dir %{bindir}
%{bindir}/tomcat-juli.jar
%exclude %{libdir}/%{name}-el-%{elspec}-api.jar
%exclude %{libdir}/%{name}*-embed-*.jar
# bnc#418664
%dir %{_sysconfdir}/ant.d
%config(noreplace) %{_sysconfdir}/ant.d/catalina-ant

%files embed -f output/dist/src/res/maven/.mfiles-embed
%dir %{libdir}

%files servlet-4_0-api -f output/dist/src/res/maven/.mfiles-servlet-api
%license LICENSE
%{_javadir}/%{name}-servlet-%{servletspec}-api.jar
%{_javadir}/%{name}-servlet-api.jar
%{_javadir}/%{name}-servlet.jar
%ghost %{_sysconfdir}/alternatives/servlet

%files webapps
#bnc#520532
%config(noreplace) %{tomcatappdir}/ROOT
%{tomcatappdir}/examples
%{tomcatappdir}/sample

%files jsvc
%defattr(755,root,root,0755)
%attr(0644,root,root) %{_unitdir}/%{name}-jsvc.service
%{_sbindir}/rc%{name}-jsvc

%changelog
* Mon Mar 30 2020 Matei Albu <malbu@suse.com>
- Update to Tomcat 9.0.33. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.33_(markt)
- Notable fix: corrected a regression in the improvements to HTTP
  header parsing (bsc#1167438)
- Fix NoSuchMethodError in the HTTP APR connector when using
  openjdk 1.8 (bsc#1161083)
- Rebased patches:
  * tomcat-9.0-javadoc.patch
  * tomcat-9.0-disable-osgi-build.patch
  * tomcat-9.0.31-java8compat.patch
* Fri Feb 28 2020 Matei Albu <malbu@suse.com>
- Change default value of AJP connector secretRequired to false
- Added patch:
  * tomcat-9.0.31-secretRequired-default.patch
* Tue Feb 25 2020 Fridrich Strba <fstrba@suse.com>
- Update to Tomcat 9.0.31. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.30_(markt)
- Fixed CVEs:
  * CVE-2019-17569 (bsc#1164825)
  * CVE-2020-1935 (bsc#1164860)
  * CVE-2020-1938 (bsc#1164692)
- Modified patch
  * tomcat-9.0.30-java8compat.patch
  - > tomcat-9.0.31-java8compat.patch
    + Adapt to changed context
* Wed Jan 29 2020 Matei Albu <malbu@suse.com>
- Modified patch:
  * tomcat-9.0.30-java8compat.patch
    + add missing casts (bsc#1162081)
* Mon Jan 20 2020 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * tomcat-9.0.30-java8compat.patch
    + Cast java.nio.ByteBuffer and java.nio.CharBuffer to
    java.nio.Buffer in order to avoid calling Java 9+ APIs
    (functions with co-variant return types) (bsc#1161025)
* Tue Dec 24 2019 Matei Albu <malbu@suse.com>
- Update to Tomcat 9.0.30. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.30_(markt)
- Fixed CVEs:
  - CVE-2019-12418 (bsc#1159723)
  - CVE-2019-17563 (bsc#1159729)
- Rebased patch:
  - tomcat-9.0-JDTCompiler-java.patch
  - tomcat-9.0-javadoc.patch
* Thu Jul  4 2019 Matei Albu <malbu@suse.com>
- Update to Tomcat 9.0.21. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.21_(markt)
- Rebased patch:
  - tomcat-9.0-javadoc.patch
  - tomcat-9.0-disable-osgi-build.patch
  - tomcat-9.0-javac-release.patch
* Tue May 21 2019 Matei Albu <malbu@suse.com>
- Update to Tomcat 9.0.20. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.20_(markt)
  Notable packaging changes:
  - File /usr/share/java/tomcat/catalina-jmx-remote.jar was removed.
    The classes contained in this jar were merged into
    /usr/share/java/tomcat/catalina.jar.
- increase maximum number of threads and open files for tomcat (bsc#1111966)
- Fixed CVEs:
  - CVE-2019-10072 (bsc#1139924)
  - CVE-2019-0199 (bsc#1131055)
  - CVE-2019-0221 (bsc#1136085)
- Rebased patch:
  - tomcat-9.0-JDTCompiler-java.patch
  - tomcat-9.0-javadoc.patch
* Tue Feb 19 2019 malbu@suse.com
- Don't overwrite changes made to server.xml contexts when updating
  bundled webapps.
* Mon Feb 18 2019 malbu@suse.com
- Set javac target to 1.8 when building docs samples and serverxmltool
* Tue Feb  5 2019 malbu@suse.com
- Move webapps bundled with Tomcat to /usr/share/tomcat/tomcat-webapps
  (bsc#1092341). Affected packages:
  - tomcat-webapps
  - tomcat-admin-webapps
  - tomcat-docs-webapp
- Remove %%doc directive from tomcat-docs-webapps files section so that
  zypper installs files even if rpm.install.excludedocs is set to yes.
* Mon Feb  4 2019 malbu@suse.com
- Require Java 1.8 or later (bsc#1123407)
* Sat Jan 26 2019 Fridrich Strba <fstrba@suse.com>
- Clean up OSGi manifest injection
- Put embed maven metadata into embed subpackage
- Use the .mfiles* lists generated by %%%%add_maven_depmap macro
* Wed Jan 16 2019 malbu@suse.com
- Fix tomcat-tool-wrapper classpath error (bsc#1120745)
* Fri Jan 11 2019 malbu@suse.com
- Fix tomcat-digest classpath error (bsc#1120745)
* Sat Dec 29 2018 ecsos@opensuse.org
- Update to Tomcat 9.0.14. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.14_(markt)
* Wed Dec  5 2018 Fridrich Strba <fstrba@suse.com>
- Add pom files for tomcat-jdbc and tomcat-dbcp
- Add org.eclipse.jetty.orbit* aliases to correspondant artifacts
* Fri Nov  9 2018 sean@suspend.net
- Update to Tomcat 9.0.13. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.13_(markt)
* Thu Oct 18 2018 malbu@suse.com
- Update to Tomcat 9.0.12. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.12_(markt)
- Fixed CVEs:
  - CVE-2018-11784 (bsc#1110850)
- Rebased patches:
  - tomcat-9.0-disable-osgi-build.patch
  - tomcat-9.0-javadoc.patch
  - tomcat-9.0-sle.catalina.policy.patch
  - tomcat-9.0-tomcat-users-webapp.patch
* Tue Sep 11 2018 ecsos@opensuse.org
- Declare following files to config(noreplace) to prevent override
  access rights:
  - host-manager/META-INF/context.xml
  - manager/META-INF/context.xml
* Sun Aug 26 2018 malbu@suse.com
- Empty tomcat-9.0.sysconfig to avoid overwriting of customer's
  configuration during update (bsc#1067720)
* Thu Aug 16 2018 malbu@suse.com
- Update to Tomcat 9.0.10. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.10_(markt)
- Fixed CVEs:
  - CVE-2018-1336 (bsc#1102400)
  - CVE-2018-8014 (bsc#1093697)
  - CVE-2018-8034 (bsc#1102379)
  - CVE-2018-8037 (bsc#1102410)
- Rebased patch tomcat-9.0-JDTCompiler-java.patch
- Added patch tomcat-9.0-disable-osgi-build.patch to disable adding
  OSGi metadata to JAR files
* Fri Feb 16 2018 malbu@suse.de
- Update to Tomcat 9.0.5. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.5_(markt)
* Wed Jan 17 2018 fstrba@suse.com
- Modified patch:
  * tomcat-9.0-javadoc.patch
    + Don't append to javadoc --add-modules since we are building
    with source=8
    + Avoid accessing Internet URLs from build environment
* Fri Dec  1 2017 malbu@suse.com
- Update to Tomcat 9.0.2:
  * Major update for tomcat8 from tomcat9
  * For full changelog please read upstream changes at:
    + http://tomcat.apache.org/tomcat-9.0-doc/changelog.html
  * Rename all tomcat-8.0-* files to tomcat-9.0-*
- Changed patches:
  * Deleted: tomcat-8.0-bootstrap-MANIFEST.MF.patch
  * Deleted: tomcat-8.0-sle.catalina.policy.patch
  * Deleted: tomcat-8.0-tomcat-users-webapp.patch
  * Deleted: tomcat-8.0.33-JDTCompiler-java.patch
  * Deleted: tomcat-8.0.44-javadoc.patch
  * Deleted: tomcat-8.0.9-property-build.windows.patch
  * Added: tomcat-9.0-JDTCompiler-java.patch
  * Added: tomcat-9.0-bootstrap-MANIFEST.MF.patch
  * Added: tomcat-9.0-javadoc.patch
  * Added: tomcat-9.0-sle.catalina.policy.patch
  * Added: tomcat-9.0-tomcat-users-webapp.patch
- Renamed subpackage tomcat-3_1-api to tomcat-4_0-api
  to reflect the new Servlet API version.
- Commented out JAVA_HOME in /etc/tomcat/tomcat.conf
- Added "tomcat-" prefix to lib symlinks under
  /usr/share/java to avoid file conflicts with servletapi5
  and geronimo-specs
- Fixed wrong %%ghost file paths for alternatives symlinks
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Oct 23 2017 malbu@suse.com
- Build with JDK 8 to fix runtime errors when running with JDK 7
  and 8
- Fix tomcat-digest classpath error (bsc#977410)
- Fix packaged /etc/alternatives symlinks for api libs that caused
  rpm -V to report link mismatch (bsc#1019016)
* Mon Oct 23 2017 ecsos@opensuse.org
- update to 8.0.47
  http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Fixed CVE:
  - CVE-2017-12617
- rebase tomcat-8.0-sle.catalina.policy.patch
* Tue Sep 19 2017 fstrba@suse.com
- Added patch:
  * tomcat-8.0.44-javadoc.patch
  - generate documentation with the same source level as class
    files
  - fixes build with jdk9
* Fri Jun  9 2017 ecsos@opensuse.org
- Version update to 8.0.44:
  http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Fixed CVE:
  - CVE-2017-5664 (bsc#1042910)
* Fri May 19 2017 dziolkowski@suse.com
- New build dependency: javapackages-local
* Tue May  9 2017 malbu@suse.com
- Version update to 8.0.43:
  * Another bugfix release, for full details see:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Fixed CVEs:
  - CVE-2017-5647 (bnc#1033448)
  - CVE-2017-5648 (bnc#1033447)
  - CVE-2016-8745
- Renamed and rebased patches:
  * tomcat-7.0-sle.catalina.policy.patch -> tomcat-8.0-sle.catalina.policy.patch
- Enable optional setenv.sh script. See section
  "(3.4) Using the "setenv" script (optional, recommended)" in
  http://tomcat.apache.org/tomcat-8.0-doc/RUNNING.txt
  (bnc#1002662)
- Fix file conflicts when upgrading from SLES 12 to SLES 12 SP1 (bnc#1023412).
  Added explicit obsoletes for tomcat-el-2_2-api, tomcat-jsp-2_2-api,
  tomcat-servlet-3_0-api
* Wed Dec 21 2016 astieger@suse.com
- update to 8.0.39: (boo#1003911)
  * Improve handling of I/O errors with async processing
  * Fail earlier on invalid HTTP request
- includes changes from  8.0.38:
  * Refactoring the non-container thread Async complete()/dispatch()
    handling to remove the possibility of deadlock
  * Improved UTF-8 handling for the RewriteValve
- includes changes from 8.0.37:
  * Treat paths used to obtain a request dispatcher as encoded
    (configurable)
  * Various jdbc-pool fixes
- drop tomcat-8.0.36-jar-scanner-loop.patch, upstream
* Thu Sep 29 2016 tchvatal@suse.com
- Switch to commons-dbcp2 fate#321029
* Fri Sep  2 2016 malbu@suse.com
- Backport fix for inifinite loop in the jar scanner for 8.0.36. (bnc#993862)
  Added: tomcat-8.0.36-jar-scanner-loop.patch
* Wed Jul  6 2016 malbu@suse.com
- Version update to 8.0.36:
  * Another bugfix release for the 8.0 series. Full details:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.36_(markt)
- CVE fixed by the version update:
  - CVE-2016-3092 (bnc#986359)
- Fixed a deployment error in the examples webapp by changing the context.xml format to the new one
  introduced by Tomcat 8. See http://tomcat.apache.org/migration-8.html#Web_application_resources
* Mon May  2 2016 dmacvicar@suse.de
- fix maven fragments paths to build in multiple distribution
  versions
* Thu Apr 21 2016 jcnengel@gmail.com
- Version update to 8.0.33:
  * Another bugfix release for 8.0 series, full details:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.33_(markt)
- Rebase tomcat-8.0-tomcat-users-webapp.patch
- Rebase tomcat-7.0.53-JDTCompiler-java.patch
  to tomcat-8.0.33-JDTCompiler-java.patch
* Thu Apr  7 2016 tchvatal@suse.com
- Fix fixme for the prereq preamble value
- It seems systemd prints error on adding the @ services to macros
  so do not do that
* Thu Mar 31 2016 dmacvicar@suse.de
- package was partly merged with the scripts used in the
  Fedora distribution
- support running multiple tomcat instances on the same server
  (fate#317783)
- add catalina-jmx-remote.jar (fate#318403)
- remove sysvinit support: systemd is required
* Mon Feb 29 2016 dmacvicar@suse.de
- update changes file for CVE information
- Fixed CVEs:
  - CVE-2015-5346 (bnc#967814) in 8.0.32
  - CVE-2015-5351 (bnc#967812) in 8.0.32
  - CVE-2016-0706 (bnc#967815) in 8.0.32
  - CVE-2016-0714 (bnc#967964) in 8.0.32
  - CVE-2016-0763 (bnc#967966) in 8.0.32
  - CVE-2015-5345 (bnc#967965) in 8.0.30
  - CVE-2015-5174 (bnc#967967) in 8.0.27
* Wed Feb 17 2016 tchvatal@suse.com
- Version update to 8.0.32:
  * Another bugfix release for 8.0 series, full details:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.32_(markt)
- Rebase patch:
  * tomcat-8.0.9-property-build.windows.patch
* Tue Nov 10 2015 dmacvicar@suse.de
- update to Tomcat 8.0.28
  * Multiple fixes, read upstream changelog at:
  https://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.28_(markt)
* Mon Jun  1 2015 tchvatal@suse.com
- Some whitespace cleanups
* Mon Jun  1 2015 tchvatal@suse.com
- Remove pointless conflicts on provide/obsolete symbols
* Mon Jun  1 2015 tchvatal@suse.com
- Version bump to 8.0.23 fate#318913:
  * Multiple testfixes all around, read upstream changelog at:
  http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.23_(markt)
* Tue Mar 24 2015 tchvatal@suse.com
- Fix previous commit. Fix one rpmlint warning
* Wed Mar 18 2015 tchvatal@suse.com
- Drop gpg verification from spec, it is done by obs
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new jpackage-tools
* Tue Feb 10 2015 wittemar@googlemail.com
- update to Tomcat 8.0.18:
  * Major update for tomcat8 from tomcat7
  * For full changelog please read upstream changes at:
    + http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Rename all tomcat-7.0-* files to tomcat-8.0-*
  * Update keyring file
- Update windows patch to apply again:
  * Deleted: tomcat-7.0.52-property-build.windows.patch
  * Added: tomcat-8.0.9-property-build.windows.patch
  * Added:tomcat-8.0-tomcat-users-webapp.patch
  * Deleted: tomcat-7.0-tomcat-users-webapp.patch
  * Added: tomcat-8.0-bootstrap-MANIFEST.MF.patch
  * Deleted: tomcat-7.0-bootstrap-MANIFEST.MF.patch
* Tue Feb  3 2015 bmaryniuk@suse.com
- Version 1.1.30 or higher is required for APR listener (bnc#914725)
* Wed Sep 17 2014 bmaryniuk@suse.com
- SLE12 has different path for the "rm" command than older versions.
  To avoid possible clashes, the entire coreutils must be provided.
  (bnc#894292)
* Tue Sep 16 2014 bmaryniuk@suse.com
- Fixed Security Manager policies, which makes unable properly
  run webapps by default. (bnc#891264)
  Added: tomcat-7.0-sle.catalina.policy.patch
* Tue Sep 16 2014 bmaryniuk@suse.com
- Missing security manager policy file prevents Tomcat to start
  with systemd. (bnc#890995)
* Mon Sep 15 2014 dmacvicar@suse.de
- Tomcat 7.0.55 requires ecj 4.4.0
* Mon Sep  8 2014 dmacvicar@suse.de
- include the tomcat websocket implementation (tomcat7-websocket)
* Mon Sep  8 2014 dmacvicar@suse.de
- Update to 7.0.55
  * Update to the Eclipse JDT Compiler 4.4
  * Better error handling when the error occurs after the response
    has been committed
  * Various improvements to the Mapper including fixing some
    concurrency bugs
  * See http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
* Mon Sep  8 2014 dmacvicar@suse.de
- build tomcat-embed as a subpackage
* Wed Sep  3 2014 tchvatal@suse.com
- Drop two unused defines
* Wed Sep  3 2014 dmacvicar@suse.de
- touch the alternatives files to avoid build errors
  in older versions
* Tue Jul 29 2014 tchvatal@suse.com
- Do not define default defattr as it is pointless.
* Fri Jul 25 2014 tchvatal@suse.com
- One file here was not supposed to be ghost.
* Sat Jul 19 2014 tchvatal@suse.com
- Fix once more the alternatives.
* Fri Jul 11 2014 tchvatal@suse.com
- Add path to rm command.
* Fri Jul 11 2014 tchvatal@suse.com
- Silence loads of warnings by rpmlintrc
* Thu Jul 10 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and format few things a bit.
* Thu Jul 10 2014 tchvatal@suse.com
- Remove few deps not really needed for sle11.
* Thu Jul 10 2014 tchvatal@suse.com
- Drop unused files obs.bl and local.lb
- Drop unused collections-tomcat-build.xml
* Sat May 24 2014 tchvatal@suse.com
- Version bump to 7.0.54:
  * bugfix update
  * See http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
* Thu May 15 2014 darin@darins.net
- Update to 7.0.53
  * bugfix release
  * Update the Eclipse JDT compiler to enable full Java 8 support in JSPs.
  * See http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
- Patch for Bug 56373
  * See https://issues.apache.org/bugzilla/show_bug.cgi?id=56373
  * tomcat-7.0.53-JDTCompiler-java.patch
- Rename tomcat-7.0.2-property-build.windows.patch to
  tomcat-7.0.52-property-build.windows.patch
* Thu May 15 2014 darin@darins.net
- remove saxon build requirement for sles
- disable bytecode check for sles
* Mon Apr 14 2014 darin@darins.net
- remove unknown option from fillup_only macro
- wrap systemd %%pre[un]/%%post[un] in conditional
- specify required ant version
* Tue Apr  8 2014 wittemar@googlemail.com
- Update to 7.0.52
  * bugfix release
  * Fix CVE-2014-0050, a DoS vulnerability related to multi-part processing
- Update to 7.0.50
  * bugfix release
* Thu Dec 12 2013 mvyskocil@suse.com
- Add missing commons-pool-tomcat5 symlink (bnc#847505c#13)
* Mon Nov  4 2013 mvyskocil@suse.com
- Update to 7.0.47
  * bugfix release
  * backport of JSR-356 Java WebSocket 1.0
  * package tomcat now requires java7 at lease
- Updated tomcat.keyring to reflect the fact new release is signed by
  Violeta Georgieva / D63011C7
  see http://osdir.com/ml/dev-tomcat.apache.org/2013-10/msg00849.html
- Add tomcat-dbcp.jar (bnc#847505) back into tomcat lib dir
- Install tomcat-coyote.jar as well
- Remove pointless scriplets
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Sep  5 2013 mvyskocil@suse.com
- drop a dependency on unecessary -tomcat5 packages
- use commons-dbcp.jar for build
- add missing commons-pool.jar to libdir
* Fri Aug  9 2013 mvyskocil@suse.com
- add _constraints to not schedule build on some build machines
  workaround for bnc#832762
* Tue Aug  6 2013 robert.munteanu@gmail.com
- Add missing 'su root tomcat' line to logrotate. See also
  https://bugzilla.redhat.com/show_bug.cgi?id=790334
* Fri Jul 26 2013 mvyskocil@suse.com
- call chown --no-dereference in init script
  (bnc#822177#c7/prevents CVE-2013-1976)
* Tue Jul 23 2013 mvyskocil@suse.com
- update to 7.0.42 (bugfix release)
  see http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
- fix file list to be compatible for new rpm
* Thu Apr 18 2013 mvyskocil@suse.com
- update to 7.0.39 (bugfix release)
- install only systemd unit files on openSUSE 12.1+
  * and call proper code when init script still exists
- add a proper scripplets for -jsvc subpackage
- don't use catalina.out, systemd redirects stderr/stdout to syslog
- don't use and recommends logrotate
- package /etc/ant.d properly, mark only catalina-ant as a config file
* Sat Feb 16 2013 m407@mail.ru
- Fix tomcat init scripts generating malformed classpath
  (http://youtrack.jetbrains.com/issue/JT-18545)
  bnc#804992
* Mon Jan 21 2013 mvyskocil@suse.com
- update to 7.0.35 (bugfix release)
  require ecj >= 4.2.1, like upstream do
- make gpg-offline work distros after 12.2
* Thu Dec 27 2012 archie@dellroad.org
- Ensure tomcat stdout/stderr output ends up in catalina.out
* Thu Dec 20 2012 archie@dellroad.org
- Recommend libtcnative-1-0 >= 1.1.24
- /etc/init.d/tomcate init script fixes:
  * Include /usr/bin and /usr/sbin in the PATH
  * Fix logic for cleaning the work directories
  * Fix typo (log_success_msg lsb function name)
  * Fix typo (reload message)
- Require log4j
* Tue Dec 18 2012 mvyskocil@suse.com
- Require gpg-offline on 12.2+
* Thu Nov 29 2012 sbrabec@suse.cz
- Verify GPG signature.
* Mon Nov 26 2012 mvyskocil@suse.com
- update to 7.0.33 (bugfix release)
* Tue Sep 11 2012 mvyskocil@suse.cz
- update to 7.0.30 (bugfix release)
  * SSI and CGI disabled by default
- fix bnc#779538: change the working dir to $CATALINA_BASE
- document the CATALINA_BASE and CATALINA_HOME in tomcat.conf better
- fix rpmlintrc file
* Thu Jul 19 2012 mvyskocil@suse.cz
- fix bnc#771802 - systemd support is broken
  * change type froking to simple as it does not make a sense run java in a
    background to emulate that
  * remove the need of nested wrappers, so /usr/sbin/tomcat-sysd now relies on
    systemd features like User/EnvironmentFile
  * workaround the 143 exit code in Stop phase - return 0 in this case
  * merge the jsvc into tomcat-sysd code, the -jsvc-sysd is a symlink
  * properly use jsvc with pid file to start and stop
* Wed Jun 13 2012 mvyskocil@suse.cz
- update to 7.0.26 (bugfix release)
- rename package to tomcat in order to emphasise a fact, there is only one
  major release of tomcat maintained in distribution
- add manifest files and systemd support (thanks Fedora)
- create tomcat-jsvc package
* Thu Feb 23 2012 mvyskocil@suse.cz
- update to 7.0.26 (bugfix release)
- fix bnc#747771 - don't use /var/lock/subsys
  sync tomcat7 init with tomcat6
* Sun Feb 19 2012 wittemar@googlemail.com
- update to 7.0.25 (bugfix release)
* Tue Nov  1 2011 mvyskocil@suse.cz
- update to 7.0.22 (bugfix release)
- wrote changes and prepare for inclusion to openSUSE distribution
- fix bnc#726307
  /etc/tomcat7 is writtable for tomcat group
* Mon Sep 19 2011 wittemar@googlemail.com
- update to version 7.0.21
* Thu Jul 21 2011 mvyskocil@suse.cz
- update to version 7.0.16 (bugfix update)
* Wed Mar 30 2011 jrenner@suse.de
- add rpmlintrc, digest, init and wrapper scripts and config file
  - build require geronimo apis and wsdl4j
  - disable webservices in javadoc target
* Tue Jan 18 2011 mvyskocil@suse.cz
- initial packaging of tomcat7 7.0.6
